@@ -1,6 +1,6 @@
 # window.py
 #
-# Copyright 2018-2022 Romain F. T.
+# Copyright 2018-2023 Romain F. T.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -88,7 +88,7 @@ class DrWindow(Gtk.ApplicationWindow):
 
 		This method is called asynchronously, which isn't *correct* (not very
 		thread-safe or anything) but it allows the window to be shown quicker.
-		If it fails, a window is here anyway because this is independant from
+		If it fails, a window is here anyway because this is independent from
 		the object constructor."""
 
 		self.reveal_action_report(_("Error starting the application, please" + \
@@ -131,6 +131,9 @@ class DrWindow(Gtk.ApplicationWindow):
 		return False
 
 	def _try_show_release_notes(self):
+		"""Add specific actions to the primary menu if the current version is a
+		new one (the corresponding release notes have never been opened or
+		dismissed)"""
 		last_version = self.gsettings.get_string('last-version')
 		current_version = self.app.get_current_version()
 		if current_version == last_version:
@@ -432,7 +435,7 @@ class DrWindow(Gtk.ApplicationWindow):
 		# What happens when the active image change
 		self.notebook.connect('switch-page', self.on_active_tab_changed)
 
-		# Select tools using "alt" mnemonics
+		# Change the active tool using "alt" mnemonics
 		self.connect('key-press-event', self._check_for_alt_key)
 		self.connect('key-release-event', self._check_for_alt_key)
 
@@ -549,8 +552,8 @@ class DrWindow(Gtk.ApplicationWindow):
 		self.add_action_simple('new_tab_clipboard', \
 		                    self.build_image_from_clipboard, ['<Ctrl><Shift>v'])
 		self.add_action_simple('open', self.action_open, ['<Ctrl>o'])
-		self.add_action_simple('tab_left', self.action_tab_left, ['<Ctrl><Shift>Left'])
-		self.add_action_simple('tab_right', self.action_tab_right, ['<Ctrl><Shift>Right'])
+		self.add_action_simple('tab_right', self.action_tab_right, ['<Ctrl>Tab'])
+		self.add_action_simple('tab_left', self.action_tab_left, ['<Ctrl><Shift>Tab'])
 		self.add_action_simple('close_tab', self.action_close_tab, ['<Ctrl>w'])
 		self.add_action_simple('close', self.action_close_window)
 
@@ -632,7 +635,7 @@ class DrWindow(Gtk.ApplicationWindow):
 
 	def show_info_settings(self, *args):
 		"""This is executed when a setting changed but the method to apply it
-		immediatly in the current window doesn't exist."""
+		immediately in the current window doesn't exist."""
 		self.reveal_message(_("Modifications will take effect in the next new window."))
 
 	def update_picture_title(self, main_title=None):
@@ -938,6 +941,8 @@ class DrWindow(Gtk.ApplicationWindow):
 		return self.tools[self.former_tool_id]
 
 	def back_to_previous(self, *args):
+		"""Switch back to the previously active tool, if it's different from the
+		current one."""
 		if self.former_tool_id == self.active_tool_id:
 			self.force_selection()
 			# avoid cases where applying a transform tool keeps the tool active
@@ -1188,7 +1193,7 @@ class DrWindow(Gtk.ApplicationWindow):
 	def action_paste(self, *args):
 		"""By default, this action pastes an image, but if there is no image in
 		the clipboard, it will paste text using the text tool. Once the text
-		tool is active, this action is disabled to not interfer with the default
+		tool is active, this action is disabled to not interfere with the default
 		behavior of ctrl+v provided by the GTK text entry."""
 		cb = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
 		pixbuf = cb.wait_for_image()
